==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-MX/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Este usuario puede iniciar sesión',
    'activated_disabled_help_text' => 'No puedes editar el estado de activación para tu propia cuenta.',
    'assets_user'       => 'Equipos asignados a :name',
    'bulk_update_warn'	=> 'Estás a punto de modificar las propiedades de :user_count usuarios. Por favor, ten en cuenta que no puedes modificar las propiedades de tu propio usuario con este formulario, y debes realizar las modificaciones a tu propio usuario de forma individual.',
    'bulk_update_help'	=> 'Este formulario permite actualizar múltiples usuarios simultáneamente. Rellena únicamente los campos que necesites cambiar. Cualquier campo que quede en blanco no se actualizará.',
    'current_assets'    => 'Equipos checked out a este usuario',
    'clone'             => 'Clonar Usuario',
    'contact_user'      => 'Contacta con :name',
    'edit'              => 'Editar Usuario',
    'filetype_info'     => 'Tipos de archivos permitidos son png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, y rar.',
    'history_user'      => 'Historial de :name',
	'info'				=> 'Información',
    'restore_user'		=> 'Haga clic aquí para restaurarlos.',
    'last_login'        => 'Último acceso',
    'ldap_config_text'  => 'Las configuraciones de LDAP estàn en: Admin -> Settings. La ubicaciòn seleccionadada sera asignada a todos los usuarios importados.',
    'print_assigned'    => 'Imprimir todos los Asignados',
    'software_user'     => 'Software asignado a :name',
    'send_email_help'   => 'Debe proporcionar una dirección de correo electrónico para que este usuario para enviar las credenciales. Las credenciales de correo electrónico sólo se pueden hacer en la creación del usuario. Las contraseñas se almacenan en un hash de un solo sentido y no se pueden recuperar una vez guardadas.',
    'view_user'         => 'Ver Usuario :name',
    'usercsv'           => 'Archivo CSV',
    'two_factor_admin_optin_help' => 'La actual configuración de administración permite cumplimiento selectivo de autenticación de dos factores.  ',
    'two_factor_enrolled' => 'Dispositivo con 2FA inscrito ',
    'two_factor_active'   => '2FA Activo ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-MX/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Este usuario puede iniciar sesión',
    'activated_disabled_help_text' => 'No puedes editar el estado de activación para tu propia cuenta.',
    'assets_user'       => 'Equipos asignados a :name',
    'bulk_update_warn'	=> 'Estás a punto de modificar las propiedades de :user_count usuarios. Por favor, ten en cuenta que no puedes modificar las propiedades de tu propio usuario con este formulario, y debes realizar las modificaciones a tu propio usuario de forma individual.',
    'bulk_update_help'	=> 'Este formulario permite actualizar múltiples usuarios simultáneamente. Rellena únicamente los campos que necesites cambiar. Cualquier campo que quede en blanco no se actualizará.',
    'current_assets'    => 'Equipos checked out a este usuario',
    'clone'             => 'Clonar Usuario',
    'contact_user'      => 'Contacta con :name',
    'edit'              => 'Editar Usuario',
    'filetype_info'     => 'Tipos de archivos permitidos son png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, y rar.',
    'history_user'      => 'Historial de :name',
    'info'				=> 'Información',
    'restore_user'		=> 'Haga clic aquí para restaurarlos.',
    'last_login'        => 'Último acceso',
    'ldap_config_text'  => 'Las configuraciones de LDAP estàn en: Admin -> Settings. La ubicaciòn seleccionadada sera asignada a todos los usuarios importados.',
    'print_assigned'    => 'Imprimir todos los Asignados',
    'software_user'     => 'Software asignado a :name',
    'send_email_help'   => 'Debe proporcionar una dirección de correo electrónico para que este usuario para enviar las credenciales. Las credenciales de correo electrónico sólo se pueden hacer en la creación del usuario. Las contraseñas se almacenan en un hash de un solo sentido y no se pueden recuperar una vez guardadas.',
    'view_user'         => 'Ver Usuario :name',
    'usercsv'           => 'Archivo CSV',
    'two_factor_admin_optin_help' => 'La actual configuración de administración permite cumplimiento selectivo de autenticación de dos factores.  ',
    'two_factor_enrolled' => 'Dispositivo con 2FA inscrito ',
    'two_factor_active'   => '2FA Activo ',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
